==> apache-beam-2.42.0-source-release.zip: beam-2.42.0/learning/tour-of-beam/frontend/README.md <==
<!--
     Licensed to the Apache Software Foundation (ASF) under one
     or more contributor license agreements.  See the NOTICE file
     distributed with this work for additional information
     regarding copyright ownership.  The ASF licenses this file
     to you under the Apache License, Version 2.0 (the
     "License"); you may not use this file except in compliance
     with the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing,
     software distributed under the License is distributed on an
     "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
     KIND, either express or implied.  See the License for the
     specific language governing permissions and limitations
     under the License.
 -->

 # Tour of Beam
 These are the main sources of the Tour of Beam website.

 # About

 # Getting started
 Flutter installation guide: https://docs.flutter.dev/get-started/install
 Run the app: `flutter run --web-renderer html`

 # Deployment

 # Tests
 Install ChromeDriver to run integration tests in a browser: https://docs.flutter.dev/testing/integration-tests#running-in-a-browser
 Run integration tests:
 flutter drive \
   --driver=test_driver/integration_test.dart \
   --target=integration_test/counter_test.dart \
   -d web-server

 # Packages
 `flutter pub get`

 # Contribution guide
 For checks: `./gradlew rat`

 # Additional resources

 # Troubleshooting

==> apache-beam-2.44.0-source-release.zip: beam-2.44.0/learning/tour-of-beam/frontend/README.md <==
<!--
     Licensed to the Apache Software Foundation (ASF) under one
     or more contributor license agreements.  See the NOTICE file
     distributed with this work for additional information
     regarding copyright ownership.  The ASF licenses this file
     to you under the Apache License, Version 2.0 (the
     "License"); you may not use this file except in compliance
     with the License.  You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

     Unless required by applicable law or agreed to in writing,
     software distributed under the License is distributed on an
     "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
     KIND, either express or implied.  See the License for the
     specific language governing permissions and limitations
     under the License.
 -->

 # Tour of Beam
 These are the main sources of the Tour of Beam website.

 # About

## Getting started
Running, debugging, and testing all require this first step that fetches
dependencies and generates code:

```bash
cd ../../../playground/frontend/playground_components
flutter pub get
flutter pub run build_runner build
cd ../../../learning/tour-of-beam/frontend
flutter pub get
flutter pub run build_runner build
```

### Run

The following command is used to build and serve the frontend app locally:

`$ flutter run -d chrome`


 # Deployment

 # Tests
 Install ChromeDriver to run integration tests in a browser: https://docs.flutter.dev/testing/integration-tests#running-in-a-browser
 Run integration tests:
 flutter drive \
   --driver=test_driver/integration_test.dart \
   --target=integration_test/counter_test.dart \
   -d web-server

 # Packages
 `flutter pub get`

 # Contribution guide
 For checks: `./gradlew rat`

 # Additional resources

 # Troubleshooting
